@@ -1,3 +1,3 @@
 from chemdraw.objects.molecule import Molecule
-from chemdraw.drawers.drawer import Drawer, DrawerConfig
+from chemdraw.drawers.drawer import Drawer, ConfigDrawer
 from chemdraw.drawers.drawer_grid import GridDrawer, GridConfig
